@@ -21,7 +21,7 @@ pretty_errors.configure(
 )
 
 logger.remove(0)
-# logger.add(sys.stderr, level="DEBUG")
+#logger.add(sys.stderr, level="TRACE")
 #logger.add(sys.stderr, level="CRITICAL")
 
 
@@ -229,6 +229,7 @@ class DellApi:
             return b
 
     def _warranty_handler(self, resp: list) -> list[dict]:
+        logger.debug('data into handler: {}', resp)
         data = []  # ServiceTag, Region, Warranty, Elapsed, EndDate
 
         for tag in resp:
@@ -285,8 +286,9 @@ class DellApi:
                              'Start Date': '',
                              "End Date": '',
                              })
+        logger.debug(data)
 
-        return data
+        return data[::-1]
 
     def servicetags_from_file(self, abspath) -> list:
         with open(f"{abspath}") as f:
@@ -382,7 +384,6 @@ def main():
 
     args = parser.parse_args()
     logger.debug("argparse namespace: {}", args)
-    #print(args)
 
     for command in args.__dict__:
         cv = args.__dict__[command]
